@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.1200';
+our $VERSION = '0.1201';
 
 use Moo;
 use strictures 2;
@@ -495,7 +495,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.1200
+version 0.1201
 
 =head1 SYNOPSIS
 
@@ -510,7 +510,7 @@ version 0.1200
   $dia->chord('xx0232');
   $dia->position(5);
   $dia->outfile('mystery-chord');
-  $dia->showname('Xb'); # "X flat"
+  $dia->showname('Xb dim'); # "X flat diminished"
   $dia->draw;
 
   $dia = Music::FretboardDiagram->new(
@@ -526,9 +526,9 @@ version 0.1200
     horiz    => 1,
     image    => 1,
     verbose  => 1,
-    string_color => 'blue',
+    string_color => 'black',
     fret_color   => 'darkgray',
-    dot_color    => 'gray',
+    dot_color    => 'blue',
   );
   my $image = $dia->draw;
 
@@ -537,13 +537,17 @@ version 0.1200
 A C<Music::FretboardDiagram> object draws fretboard chord diagrams including
 neck position and chord name annotations for guitar, ukulele, banjo, etc.
 
-Below are examples of a vertical guitar diagram and a horizontal ukulele diagram:
+=begin html
 
-=for html <br>
+Here are examples of a vertical guitar diagram and a horizontal ukulele diagram:
+
+<br>
 <img src="https://raw.githubusercontent.com/ology/Music-FretboardDiagram/master/chord-diagram.png">
 <img src="https://raw.githubusercontent.com/ology/Music-FretboardDiagram/master/ukulele.png">
 <br>
 
+=end html
+
 =head1 ATTRIBUTES
 
 =head2 chord
